@@ -33,7 +33,7 @@ show an individual help text for it.
 
 The correct identification of each
 help-aware widget presuppose that the
-attribute :attr:`~HelpBehaviour.ae_help_id`
+attribute :attr:`~HelpBehaviour.help_id`
 has a unique value for each widget
 instance. This is done automatically for
 the widgets provided by the
@@ -41,7 +41,7 @@ module :mod:`~ae.kivy_app` for to change
 the app flow or app states (like e.g.
 :class:`~ae.kivy_app.FlowButton`).
 
-The :attr:`~HelpBehaviour.ae_help_vars`
+The :attr:`~HelpBehaviour.help_vars`
 is a dict which can be used to provide extra
 context data for the generation and the
 display of help texts.
@@ -92,7 +92,7 @@ from ae.core import main_app_instance
 from ae.gui_help import HelpAppBase                                                         # type: ignore
 
 
-__version__ = '0.1.5'
+__version__ = '0.1.6'
 
 
 Builder.load_string("""\
@@ -103,18 +103,18 @@ Builder.load_string("""\
 
 
 <HelpBehaviour>:
-    ae_help_id: ''
-    # 'help_layout is not None' is needed because None is not allowed for bool ae_help_lock attribute/property
-    ae_help_lock: app.help_layout is not None and app.displayed_help_id != self.ae_help_id
-    ae_help_vars: dict()
+    help_id: ''
+    # 'help_layout is not None' is needed because None is not allowed for bool help_lock attribute/property
+    help_lock: app.help_layout is not None and app.displayed_help_id != self.help_id
+    help_vars: dict()
     canvas.after:
         Color:
-            rgba: app.font_color[:3] + (0.24 if self.ae_help_lock else 0, )
+            rgba: app.font_color[:3] + (0.24 if self.help_lock else 0, )
         Ellipse:
             pos: self.x + dp(9), self.y + dp(9)
             size: self.width - dp(18), self.height - dp(18)
         Color:
-            rgba: app.font_color[:3] + (0.51 if self.ae_help_lock else 0, )
+            rgba: app.font_color[:3] + (0.51 if self.help_lock else 0, )
         Line:
             width: sp(3)
             rounded_rectangle: self.x + dp(3), self.y + dp(3), self.width - dp(6), self.height - dp(6), sp(15)
@@ -162,11 +162,11 @@ Builder.load_string("""\
 
 
 <HelpToggler>:
-    ae_icon_name: 'help_icon' if app.help_layout else 'app_icon'
+    icon_name: 'help_icon' if app.help_layout else 'app_icon'
     ani_value: 0.99
     size_hint_x: None
     width: self.height
-    source: app.main_app.img_file(self.ae_icon_name, app.ae_states['font_size'], app.ae_states['light_theme'])
+    source: app.main_app.img_file(self.icon_name, app.app_states['font_size'], app.app_states['light_theme'])
     canvas.after:
         Color:
             rgba: min(self.ani_value * 1.5, 1), min(self.ani_value * 1.5, 1), 1 - self.ani_value, 1 - self.ani_value / 2
@@ -180,9 +180,9 @@ Builder.load_string("""\
 
 class HelpBehaviour(Widget):
     """ behaviour mixin class for widgets having help texts. """
-    ae_help_id = StringProperty()       #: unique help id of the widget
-    ae_help_lock = BooleanProperty()    #: True if the help mode is active and this widget is not the help target
-    ae_help_vars = DictProperty()       #: dict of exta data for to displayed/render the help text of this widget
+    help_id = StringProperty()      #: unique help id of the widget
+    help_lock = BooleanProperty()   #: True if the help mode is active and this widget is not the help target
+    help_vars = DictProperty()      #: dict of extra data for to displayed/render the help text of this widget
 
     def on_touch_down(self, touch: MotionEvent) -> bool:                                    # pragma: no cover
         """ prevent any processing if touch is done on the help activator widget or in active help mode.
@@ -195,8 +195,8 @@ class HelpBehaviour(Widget):
         if main_app.help_activator.collide_point(*touch.pos):
             return False        # allow help activator button to process this touch down event
 
-        if self.ae_help_lock and self.collide_point(*touch.pos):  # main_app.help_layout is not None
-            if main_app.help_display(self.ae_help_id, self.ae_help_vars):
+        if self.help_lock and self.collide_point(*touch.pos):  # main_app.help_layout is not None
+            if main_app.help_display(self.help_id, self.help_vars):
                 return True
 
         return super().on_touch_down(touch)
